@@ -14,7 +14,7 @@ from netbox_storage.models import LinuxDevice
 
 class LinuxDeviceForm(NetBoxModelForm):
     device = CharField(
-        label="Path",
+        label="Device Name",
         help_text="The mounted path of the volume e.g. /var/lib/docker",
     )
 
@@ -57,11 +57,11 @@ class LinuxDeviceBulkEditForm(NetBoxModelBulkEditForm):
 
     device = CharField(
         required=False,
-        label="Path",
+        label="Device",
     )
     type = CharField(
         required=False,
-        label="Path",
+        label="Type",
     )
     description = CharField(max_length=255, required=False)
 
