@@ -1,7 +1,7 @@
 from django.core.validators import MinValueValidator
 from django.forms import (
     CharField,
-    FloatField,
+    FloatField, BooleanField
 )
 from django.urls import reverse_lazy
 
@@ -53,9 +53,14 @@ class LVMTemplateForm(NetBoxModelForm):
     )
     fs_options = CharField(
         required=False,
-        label="FS Options",
+        label="Filesystem Options",
         help_text="The mounted point of the volume e.g. /var/lib/docker",
     )
+    checkbox_partition = BooleanField(
+        label="Create extra partition",
+        help_text="Create an extra partition e.g. /dev/sdb1",
+        required=False
+    )
 
     fieldsets = (
         (
@@ -63,6 +68,7 @@ class LVMTemplateForm(NetBoxModelForm):
             (
                 "drive",
                 "platform",
+                "checkbox_partition"
             ),
         ),
         (
@@ -73,7 +79,8 @@ class LVMTemplateForm(NetBoxModelForm):
                 "size",
                 "mountpoint",
                 "fs_type",
-                "fs_options"
+                "fs_options",
+                "checkbox_partition"
             ),
         ),
     )
@@ -93,6 +100,7 @@ class LVMTemplateForm(NetBoxModelForm):
         print(f"Mountpoint: {self.cleaned_data['mountpoint']}")
         print(f"Filesystem: {self.cleaned_data['fs_type']}")
         print(f"Filesystem Options: {self.cleaned_data['fs_options']}")
+        print(f"Checkbox Partition: {self.cleaned_data['checkbox_partition']}")
         self.instance.vg = self.cleaned_data['drive']
         self.instance.size = self.cleaned_data['size']
         logical_volume = super().save(*args, **kwargs)
